/*
 * Copyright (c) 2005, Innoopract Informationssysteme GmbH.
 * All rights reserved. This program and the accompanying materials
 * are made available under the terms of the Eclipse Public License v1.0
 * which accompanies this distribution, and is available at
 * http://www.eclipse.org/legal/epl-v10.html
 * 
 * Contributors:
 *  Innoopract - initial API and implementation
 */
package bug2html;

import java.util.Collections;
import java.util.HashSet;
import java.util.Set;

/**
 * Java model of a (bugzilla) Bug Node.
 * @author Elias Volanakis <evolanakis@innoopract.de>
 */
public class Bug {

  private int id;
  private String milestone = "";
  private String status = "";
  private String priority = "";
  private boolean helpWanted;
  private Set dependsOn;
  private String shortDescr = "";
  private Description longDescr = Description.EMPTY_DESCRIPTION;
  private String component = "";

  Bug() {
    // package only parameterless constructor
  }

  boolean addDependency(final Integer bugId) {
    if (bugId == null || bugId.intValue() < 1) {
      throw new IllegalArgumentException();
    }
    if (dependsOn == null) {
      dependsOn = new HashSet();
    }
    return dependsOn.add(bugId);
  }

  public String getComponent() {
    return component;
  }

  /**
   * Return the IDs of the dependencies of this bug
   * @return a Set of Integers. May be empty.
   */
  public Set getDependencies() {
    return (dependsOn == null) ? Collections.EMPTY_SET : new HashSet(dependsOn);
  }

  public int getId() {
    return id;
  }

  public Description getLongDescr() {
    return longDescr;
  }

  public String getMilestone() {
    return milestone;
  }

  public String getPriority() {
    return priority;
  }

  public String getShortDescr() {
    return shortDescr;
  }

  public String getStatus() {
    return status;
  }

  public boolean isHelpWanted() {
    return helpWanted;
  }

  void setComponent(final String component) {
    if (component == null) {
      throw new IllegalArgumentException();
    }
    this.component = component;
  }

  void setHelpWanted(final boolean helpWanted) {
    this.helpWanted = helpWanted;
  }

  void setId(int id) {
    if (id < 1) {
      throw new IllegalArgumentException();
    }
    this.id = id;
  }

  void setLongDescr(final Description longDescr) {
    if (longDescr == null) {
      throw new IllegalArgumentException();
    }
    this.longDescr = longDescr;
  }

  void setLongDescription(final Description descr) {
    if (descr == null) {
      throw new IllegalArgumentException();
    }
    this.longDescr = descr;
  }

  void setMilestone(final String milestone) {
    if (milestone == null) {
      throw new IllegalArgumentException();
    }
    this.milestone = milestone;
  }

  void setPriority(final String priority) {
    if (priority == null) {
      throw new IllegalArgumentException();
    }
    this.priority = priority;
  }

  void setShortDescr(final String shortDescr) {
    if (shortDescr == null) {
      throw new IllegalArgumentException();
    }
    this.shortDescr = shortDescr;
  }

  void setStatus(final String status) {
    if (status == null) {
      throw new IllegalArgumentException();
    }
    this.status = status;
  }
}
